WebsocketStats class

Annotations
  • @freezed

Constructors

WebsocketStats({required double cpuAbsolute, required Bytes memoryBytes, required Bytes memoryLimitBytes, required WebsocketNetworkStats network, required ServerPowerState state})
const
factory
WebsocketStats.fromJson(JsonMap json)
factory

Properties

copyWith → $WebsocketStatsCopyWith<WebsocketStats>
no setterinherited
cpuAbsolute → double
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
memoryBytes → Bytes
no setterinherited
memoryLimitBytes → Bytes
no setterinherited
network → WebsocketNetworkStats
no setterinherited
powerState → ServerPowerState
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ServerPowerState
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited